Author: markus
Date: Fri Jun  6 10:01:51 2014
New Revision: 1600837

URL: http://svn.apache.org/r1600837
Log:
NUTCH-1782 NodeWalker to return current node

Modified:
    nutch/branches/2.x/CHANGES.txt
    nutch/branches/2.x/src/java/org/apache/nutch/util/NodeWalker.java

Modified: nutch/branches/2.x/CHANGES.txt
URL: 
http://svn.apache.org/viewvc/nutch/branches/2.x/CHANGES.txt?rev=1600837&r1=1600836&r2=1600837&view=diff
==============================================================================
--- nutch/branches/2.x/CHANGES.txt (original)
+++ nutch/branches/2.x/CHANGES.txt Fri Jun  6 10:01:51 2014
@@ -2,6 +2,8 @@ Nutch Change Log
 
 Current Development
 
+* NUTCH-1782 NodeWalker to return current node (markus)
+
 * NUTCH-1781 Update gora-*-mapping.xml and gora.proeprties to reflect Gora 0.4 
(lewismc)
 
 * NUTCH-1768 Upgrade to ElasticSearch 1.1.0 (jnioche)

Modified: nutch/branches/2.x/src/java/org/apache/nutch/util/NodeWalker.java
URL: 
http://svn.apache.org/viewvc/nutch/branches/2.x/src/java/org/apache/nutch/util/NodeWalker.java?rev=1600837&r1=1600836&r2=1600837&view=diff
==============================================================================
--- nutch/branches/2.x/src/java/org/apache/nutch/util/NodeWalker.java (original)
+++ nutch/branches/2.x/src/java/org/apache/nutch/util/NodeWalker.java Fri Jun  
6 10:01:51 2014
@@ -102,7 +102,14 @@ public class NodeWalker {
   }
   
   /**
-   * Returns true if there are more nodes on the current stack.
+   * Return the current node.
+   * @return Node
+   */
+  public Node getCurrentNode() {
+    return currentNode;
+  }
+  
+  /**   * Returns true if there are more nodes on the current stack.
    * @return
    */
   public boolean hasNext() {


Reply via email to